@@ -1,9 +1,23 @@
-/* Extended Module Player
+/* Extended Module Player core player
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 #include "common.h"
@@ -12,7 +26,9 @@
 #include "period.h"
 #include "virtual.h"
 #include "mixer.h"
+#ifndef LIBXMP_CORE_PLAYER
 #include "extras.h"
+#endif
 
 #define NOT_IMPLEMENTED
 #define HAS_QUIRK(x) (m->quirk & (x))
@@ -66,6 +82,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			xc->arpeggio.memory = fxp;
 		}
 		goto fx_arpeggio;
+#ifndef LIBXMP_CORE_PLAYER
 	case FX_OKT_ARP3:
 		if (fxp != 0) {
 			xc->arpeggio.val[0] = -MSN(fxp);
@@ -91,6 +108,7 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			xc->arpeggio.size = 3;
 		}
 		break;
+#endif
 	case FX_PORTA_UP:	/* Portamento up */
 		if (fxp == 0) {
 			fxp = xc->freq.memory;
@@ -174,46 +192,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		}
 		SET(TONEPORTA);
 		break;
-	case FX_PER_PORTA_UP:	/* Persistent portamento up */
-		SET_PER(PITCHBEND);
-		xc->freq.slide = -fxp;
-		if ((xc->freq.memory = fxp) == 0)
-			RESET_PER(PITCHBEND);
-		break;
-	case FX_PER_PORTA_DN:	/* Persistent portamento down */
-		SET_PER(PITCHBEND);
-		xc->freq.slide = fxp;
-		if ((xc->freq.memory = fxp) == 0)
-			RESET_PER(PITCHBEND);
-		break;
-	case FX_PER_TPORTA:	/* Persistent tone portamento */
-		if (!IS_VALID_INSTRUMENT(xc->ins))
-			break;
-		SET_PER(TONEPORTA);
-		do_toneporta(m, xc, note);
-		xc->porta.slide = fxp;
-		if (fxp == 0)
-			RESET_PER(TONEPORTA);
-		break;
-	case FX_PER_VSLD_UP:	/* Persistent volslide up */
-		SET_PER(VOL_SLIDE);
-		xc->vol.slide = fxp;
-		if (fxp == 0)
-			RESET_PER(VOL_SLIDE);
-		break;
-	case FX_PER_VSLD_DN:	/* Persistent volslide down */
-		SET_PER(VOL_SLIDE);
-		xc->vol.slide = -fxp;
-		if (fxp == 0)
-			RESET_PER(VOL_SLIDE);
-		break;
-	case FX_SPEED_CP:	/* Set speed and ... */
-		if (fxp)
-			p->speed = fxp;
-		/* fall through */
-	case FX_PER_CANCEL:	/* Cancel persistent effects */
-		xc->per_flags = 0;
-		break;
 
 	case FX_VIBRATO:	/* Vibrato */
 		SET(VIBRATO);
@@ -223,14 +201,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		SET(VIBRATO);
 		SET_LFO_NOTZERO(&xc->vibrato, LSN(fxp), MSN(fxp));
 		break;
-	case FX_PER_VIBRATO:	/* Persistent vibrato */
-		if (LSN(fxp) != 0) {
-			SET_PER(VIBRATO);
-		} else {
-			RESET_PER(VIBRATO);
-		}
-		SET_LFO_NOTZERO(&xc->vibrato, LSN(fxp) << 2, MSN(fxp));
-		break;
 
 	case FX_TONE_VSLIDE:	/* Toneporta + vol slide */
 		if (!IS_VALID_INSTRUMENT(xc->ins))
@@ -331,47 +301,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 				RESET(VOL_SLIDE_2);
 		}		
 		break;
-	case FX_VOLSLIDE_UP:	/* Vol slide with uint8 arg */
-		if (HAS_QUIRK(QUIRK_FINEFX)) {
-			h = MSN(fxp);
-			l = LSN(fxp);
-			if (h == 0xf && l != 0) {
-				fxp &= 0x0f;
-				goto fx_f_vslide_up;
-			}
-		}
-
-		if (fxp)
-			xc->vol.slide = fxp;
-		SET(VOL_SLIDE);
-		break;
-	case FX_VOLSLIDE_DN:	/* Vol slide with uint8 arg */
-		if (HAS_QUIRK(QUIRK_FINEFX)) {
-			h = MSN(fxp);
-			l = LSN(fxp);
-			if (h == 0xf && l != 0) {
-				fxp &= 0x0f;
-				goto fx_f_vslide_dn;
-			}
-		}
-
-		if (fxp)
-			xc->vol.slide = -fxp;
-		SET(VOL_SLIDE);
-		break;
-	case FX_F_VSLIDE:	/* Fine volume slide */
-		SET(FINE_VOLS);
-		if (fxp) {
-			h = MSN(fxp);
-			l = LSN(fxp);
-			if (l == 0)
-				xc->vol.fslide = h;
-			else if (h == 0)
-				xc->vol.fslide = -l;
-			else
-				RESET(FINE_VOLS);
-		}		
-		break;
 	case FX_JUMP:		/* Order jump */
 		p->flow.pbreak = 1;
 		p->flow.jump = fxp;
@@ -467,9 +396,9 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		}
 		break;
 
-	case FX_PATT_DELAY:
-	    fx_patt_delay:
-		p->flow.delay = fxp;
+	case FX_FINETUNE:
+	      fx_finetune:
+		xc->finetune = (int16) (fxp - 0x80);
 		break;
 
 	case FX_F_VSLIDE_UP:	/* Fine volume slide up */
@@ -500,6 +429,10 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		else if (xc->freq.slide < 0)
 			xc->freq.slide *= -1;
 		break;
+	case FX_PATT_DELAY:
+	    fx_patt_delay:
+		p->flow.delay = fxp;
+		break;
 
 	case FX_S3M_SPEED:	/* Set S3M speed */
 	    fx_s3m_speed:
@@ -687,10 +620,6 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 			xc->trackvol.fslide = MSN(fxp) - LSN(fxp);
 		}
 		break;
-	case FX_FINETUNE:
-	      fx_finetune:
-		xc->finetune = (int16) (fxp - 0x80);
-		break;
 	case FX_IT_INSTFUNC:
 		switch (fxp) {
 		case 0:	/* Past note cut */
@@ -736,6 +665,49 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		m->mod.xxc[chn].rvb = fxp;
 		break;
 #endif
+
+#ifndef LIBXMP_CORE_PLAYER
+	case FX_VOLSLIDE_UP:	/* Vol slide with uint8 arg */
+		if (HAS_QUIRK(QUIRK_FINEFX)) {
+			h = MSN(fxp);
+			l = LSN(fxp);
+			if (h == 0xf && l != 0) {
+				fxp &= 0x0f;
+				goto fx_f_vslide_up;
+			}
+		}
+
+		if (fxp)
+			xc->vol.slide = fxp;
+		SET(VOL_SLIDE);
+		break;
+	case FX_VOLSLIDE_DN:	/* Vol slide with uint8 arg */
+		if (HAS_QUIRK(QUIRK_FINEFX)) {
+			h = MSN(fxp);
+			l = LSN(fxp);
+			if (h == 0xf && l != 0) {
+				fxp &= 0x0f;
+				goto fx_f_vslide_dn;
+			}
+		}
+
+		if (fxp)
+			xc->vol.slide = -fxp;
+		SET(VOL_SLIDE);
+		break;
+	case FX_F_VSLIDE:	/* Fine volume slide */
+		SET(FINE_VOLS);
+		if (fxp) {
+			h = MSN(fxp);
+			l = LSN(fxp);
+			if (l == 0)
+				xc->vol.fslide = h;
+			else if (h == 0)
+				xc->vol.fslide = -l;
+			else
+				RESET(FINE_VOLS);
+		}		
+		break;
 	case FX_NSLIDE_DN:
 	case FX_NSLIDE_UP:
 	case FX_NSLIDE_R_DN:
@@ -776,6 +748,56 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		SET(FINE_NSLIDE);
 		xc->noteslide.fslide = fxp;
 		break;
+
+	case FX_PER_VIBRATO:	/* Persistent vibrato */
+		if (LSN(fxp) != 0) {
+			SET_PER(VIBRATO);
+		} else {
+			RESET_PER(VIBRATO);
+		}
+		SET_LFO_NOTZERO(&xc->vibrato, LSN(fxp) << 2, MSN(fxp));
+		break;
+	case FX_PER_PORTA_UP:	/* Persistent portamento up */
+		SET_PER(PITCHBEND);
+		xc->freq.slide = -fxp;
+		if ((xc->freq.memory = fxp) == 0)
+			RESET_PER(PITCHBEND);
+		break;
+	case FX_PER_PORTA_DN:	/* Persistent portamento down */
+		SET_PER(PITCHBEND);
+		xc->freq.slide = fxp;
+		if ((xc->freq.memory = fxp) == 0)
+			RESET_PER(PITCHBEND);
+		break;
+	case FX_PER_TPORTA:	/* Persistent tone portamento */
+		if (!IS_VALID_INSTRUMENT(xc->ins))
+			break;
+		SET_PER(TONEPORTA);
+		do_toneporta(m, xc, note);
+		xc->porta.slide = fxp;
+		if (fxp == 0)
+			RESET_PER(TONEPORTA);
+		break;
+	case FX_PER_VSLD_UP:	/* Persistent volslide up */
+		SET_PER(VOL_SLIDE);
+		xc->vol.slide = fxp;
+		if (fxp == 0)
+			RESET_PER(VOL_SLIDE);
+		break;
+	case FX_PER_VSLD_DN:	/* Persistent volslide down */
+		SET_PER(VOL_SLIDE);
+		xc->vol.slide = -fxp;
+		if (fxp == 0)
+			RESET_PER(VOL_SLIDE);
+		break;
+	case FX_SPEED_CP:	/* Set speed and ... */
+		if (fxp)
+			p->speed = fxp;
+		/* fall through */
+	case FX_PER_CANCEL:	/* Cancel persistent effects */
+		xc->per_flags = 0;
+		break;
+#endif
 	case FX_PANBRELLO:	/* Panbrello */
 		SET(PANBRELLO);
 		SET_LFO_NOTZERO(&xc->panbrello, LSN(fxp) << 4, MSN(fxp));
@@ -784,7 +806,9 @@ void process_fx(struct context_data *ctx, struct channel_data *xc, int chn,
 		set_lfo_waveform(&xc->panbrello, fxp & 3);
 		break;
 	default:
+#ifndef LIBXMP_CORE_PLAYER
 		extras_process_fx(ctx, xc, chn, note, fxt, fxp, fnum);
+#endif
 		break;
 	}
 }
