@@ -1,19 +1,42 @@
-/* Extended Module Player
+/* Extended Module Player core player
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
+#include <stdio.h>
+#include <ctype.h>
 #include <string.h>
 #include <stdlib.h>
-#include <fnmatch.h>
+#ifdef ANDROID
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <unistd.h>
+#endif
 #include "common.h"
-#include "synth.h"
 #include "loaders/loader.h"
 
 
+#ifndef LIBXMP_CORE_PLAYER
+#include <fnmatch.h>
+#include "synth.h"
+
 /*
  * Handle special "module quirks" that can't be detected automatically
  * such as Protracker 2.x compatibility, vblank timing, etc.
@@ -73,12 +96,6 @@ static void module_quirks(struct context_data *ctx)
 	}
 }
 
-static void check_envelope(struct xmp_envelope *env)
-{
-	if (env->npt <= 0 || env->lps >= env->npt || env->lpe >= env->npt)
-		env->flg &= ~XMP_ENVELOPE_LOOP;
-}
-
 /* 
  * Check whether the given string matches one of the blacklisted glob
  * patterns. Used to filter file names stored in archive files.
@@ -109,6 +126,61 @@ int exclude_match(char *name)
 	return 0;
 }
 
+int get_temp_dir(char *buf, int size)
+{
+#if defined WIN32
+	const char def[] = "C:\\WINDOWS\\TEMP";
+	char *tmp = getenv("TEMP");
+
+	strncpy(buf, tmp ? tmp : def, size);
+	strncat(buf, "\\", size);
+#elif defined __AMIGA__
+	strncpy(buf, "T:", size);
+#elif defined ANDROID
+#define APPDIR "/sdcard/Xmp for Android"
+	struct stat st;
+	if (stat(APPDIR, &st) < 0) {
+		if (mkdir(APPDIR, 0777) < 0)
+			return -1;
+	}
+	if (stat(APPDIR "/tmp", &st) < 0) {
+		if (mkdir(APPDIR "/tmp", 0777) < 0)
+			return -1;
+	}
+	strncpy(buf, APPDIR "/tmp/", size);
+#else
+	const char def[] = "/tmp";
+	char *tmp = getenv("TMPDIR");
+
+	strncpy(buf, tmp ? tmp : def, size);
+	strncat(buf, "/", size);
+#endif
+
+	return 0;
+}
+
+#endif
+
+char *adjust_string(char *s)
+{
+	int i;
+
+	for (i = 0; i < strlen(s); i++)
+		if (!isprint((int)s[i]) || ((uint8) s[i] > 127))
+			s[i] = ' ';
+
+	while (*s && (s[strlen(s) - 1] == ' '))
+		s[strlen(s) - 1] = 0;
+
+	return s;
+}
+
+static void check_envelope(struct xmp_envelope *env)
+{
+	if (env->npt <= 0 || env->lps >= env->npt || env->lpe >= env->npt)
+		env->flg &= ~XMP_ENVELOPE_LOOP;
+}
+
 void load_prologue(struct context_data *ctx)
 {
 	struct module_data *m = &ctx->m;
@@ -138,8 +210,10 @@ void load_prologue(struct context_data *ctx)
     	m->mod.len = 0;
     	m->mod.rst = 0;
 
+#ifndef LIBXMP_CORE_PLAYER
 	m->synth = &synth_null;
 	m->extra = NULL;
+#endif
 	m->time_factor = DEFAULT_TIME_FACTOR;
 
 	for (i = 0; i < 64; i++) {
@@ -199,7 +273,9 @@ void load_epilogue(struct context_data *ctx)
 	}
 
 	p->flags = p->player_flags;
+#ifndef LIBXMP_CORE_PLAYER
 	module_quirks(ctx);
+#endif
 }
 
 int prepare_scan(struct context_data *ctx)
