@@ -300,7 +300,9 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
     uint8 b, mask[L_CHANNELS];
     int max_ch;
     int inst_map[120], inst_rmap[XMP_MAX_KEYS];
+#ifndef LIBXMP_CORE_PLAYER
     char tracker_name[40];
+#endif
     uint32 *pp_ins;		/* Pointers to instruments */
     uint32 *pp_smp;		/* Pointers to samples */
     uint32 *pp_pat;		/* Pointers to patterns */
@@ -421,6 +423,7 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     m->c4rate = C4_NTSC_RATE;
 
+#ifndef LIBXMP_CORE_PLAYER
     /* Identify tracker */
 
     switch (ifh.cwt >> 8) {
@@ -498,6 +501,9 @@ static int it_load(struct module_data *m, HIO_HANDLE *f, const int start)
 
     set_type(m, "%s IT %d.%02x", tracker_name,
 			ifh.cmwt >> 8, ifh.cmwt & 0xff);
+#else
+    set_type(m, "Impulse Tracker");
+#endif
 
     MODULE_INFO();
 
