@@ -74,7 +74,10 @@
 #include "loader.h"
 #include "s3m.h"
 #include "period.h"
+
+#ifndef LIBXMP_CORE_PLAYER
 #include "synth.h"
+#endif
 
 #define MAGIC_SCRM	MAGIC4('S','C','R','M')
 #define MAGIC_SCRI	MAGIC4('S','C','R','I')
@@ -194,14 +197,16 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 {
     struct xmp_module *mod = &m->mod;
     int c, r, i;
-    struct s3m_adlib_header sah;
     struct xmp_event *event = 0, dummy;
     struct s3m_file_header sfh;
     struct s3m_instrument_header sih;
-    int pat_len;
-    uint8 n, b, x8;
+#ifndef LIBXMP_CORE_PLAYER
+    struct s3m_adlib_header sah;
     char tracker_name[40];
     int quirk87 = 0;
+#endif
+    int pat_len;
+    uint8 n, b, x8;
     uint16 *pp_ins;		/* Parapointers to instruments */
     uint16 *pp_pat;		/* Parapointers to patterns */
     int ret;
@@ -235,6 +240,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	return -1;
 #endif
 
+#ifndef LIBXMP_CORE_PLAYER
     /* S3M anomaly in return_of_litmus.s3m */
     if (sfh.version == 0x1301 && sfh.name[27] == 0x87)
 	quirk87 = 1;
@@ -244,6 +250,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	fix87(sfh.patnum);
 	fix87(sfh.flags);
     }
+#endif
 
     copy_adjust(mod->name, sfh.name, 28);
 
@@ -321,6 +328,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
     if (sfh.version == 0x1300)
 	m->quirk |= QUIRK_VSALL;
 
+#ifndef LIBXMP_CORE_PLAYER
     switch (sfh.version >> 12) {
     case 1:
 	snprintf(tracker_name, 40, "Scream Tracker %d.%02x",
@@ -360,7 +368,10 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	snprintf(tracker_name, 40, "unknown (%04x)", sfh.version);
     }
 
-    snprintf(mod->type, XMP_NAME_SIZE, "%s S3M", tracker_name);
+    set_type(m, "%s S3M", tracker_name);
+#else
+    set_type(m, "Scream Tracker 3");
+#endif
 
     MODULE_INFO();
 
@@ -450,6 +461,7 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	sub->sid = i;
 
 	if (x8 >= 2) {
+#ifndef LIBXMP_CORE_PLAYER
 	    /* OPL2 FM instrument */
 
 	    hio_read(&sah.dosname, 12, 1, f);	/* DOS file name */
@@ -483,6 +495,9 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    D_(D_INFO "[%2X] %-28.28s", i, xxi->name);
 
 	    continue;
+#else
+	    goto err3;
+#endif
 	}
 
 	hio_read(&sih.dosname, 13, 1, f);	/* DOS file name */
@@ -508,12 +523,14 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	    goto err3;
 	}
 
+#ifndef LIBXMP_CORE_PLAYER
 	if (quirk87) {
 	    fix87(sih.length);
 	    fix87(sih.loopbeg);
 	    fix87(sih.loopend);
 	    fix87(sih.flags);
 	}
+#endif
 
 	xxs->len = sih.length;
 	xxi->nsm = sih.length > 0 ? 1 : 0;
@@ -550,7 +567,9 @@ static int s3m_load(struct module_data *m, HIO_HANDLE *f, const int start)
     free(pp_pat);
     free(pp_ins);
 
+#ifndef LIBXMP_CORE_PLAYER
     m->synth = &synth_adlib;
+#endif
     m->quirk |= QUIRKS_ST3;
     m->read_event_type = READ_EVENT_ST3;
 
