@@ -238,7 +238,7 @@ static int st_load(struct module_data *m, HIO_HANDLE *f, const int start)
 	mod->xxi[i].sub[0].pan = 0x80;
 	mod->xxi[i].sub[0].sid = i;
 	strncpy((char *)mod->xxi[i].name, (char *)mh.ins[i].name, 22);
-	str_adj((char *)mod->xxi[i].name);
+	adjust_string((char *)mod->xxi[i].name);
 
 	if (mod->xxs[i].len > 0)
 		mod->xxi[i].nsm = 1;
