@@ -1,9 +1,23 @@
-/* Extended Module Player
+/* Extended Module Player core player
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 /*
@@ -29,9 +43,11 @@
 #include "period.h"
 #include "effects.h"
 #include "player.h"
-#include "synth.h"
 #include "mixer.h"
+#ifndef LIBXMP_CORE_PLAYER
+#include "synth.h"
 #include "extras.h"
+#endif
 
 /* Values for multi-retrig */
 static const struct retrig_control rval[] = {
@@ -102,6 +118,7 @@ static void reset_channels(struct context_data *ctx)
 	struct channel_data *xc;
 	int i;
 
+#ifndef LIBXMP_CORE_PLAYER
 	m->synth->reset(ctx);
 
 	for (i = 0; i < p->virt.virt_channels; i++) {
@@ -114,6 +131,13 @@ static void reset_channels(struct context_data *ctx)
 		reset_channel_extras(ctx, xc);
 		xc->ins = xc->key = -1;
 	}
+#else
+	for (i = 0; i < p->virt.virt_channels; i++) {
+		xc = &p->xc_data[i];
+		memset(xc, 0, sizeof (struct channel_data));
+		xc->ins = xc->key = -1;
+	}
+#endif
 
 	for (i = 0; i < p->virt.num_tracks; i++) {
 		xc = &p->xc_data[i];
@@ -163,7 +187,7 @@ static int check_delay(struct context_data *ctx, struct xmp_event *e, int chn)
 		if (e->note == 0)
 			xc->delayed_event.note = xc->key + 1;
 		if (e->ins == 0)
-			xc->delayed_event.ins = xc->ins + 1;
+			xc->delayed_event.ins = xc->old_ins;
 	}
 
 	return 1;
@@ -178,6 +202,12 @@ static inline void read_row(struct context_data *ctx, int pat, int row)
 	struct flow_control *f = &p->flow;
 	struct xmp_event *event;
 
+	/* FIXME: workaround for pattern delay + break) */
+	if (f->skip_fetch) {
+		f->skip_fetch = 0;
+		return;
+	}
+
 	for (chn = 0; chn < mod->chn; chn++) {
 		if (row < mod->xxt[TRACK_NUM(pat, chn)]->rows) {
 			event = &EVENT(pat, chn, row);
@@ -296,7 +326,11 @@ static void process_volume(struct context_data *ctx, int chn, int t, int act)
 		return;
 	}
 
+#ifndef LIBXMP_CORE_PLAYER
 	finalvol = extras_get_volume(ctx, xc);
+#else
+	finalvol = xc->volume;
+#endif
 
 	if (TEST(TREMOLO)) {
 		finalvol += get_lfo(&xc->tremolo, 1 << 6);
@@ -319,12 +353,14 @@ static void process_volume(struct context_data *ctx, int chn, int t, int act)
 	/* Apply channel volume */
 	finalvol = finalvol * get_channel_vol(ctx, chn) / 100;
 
+#ifndef LIBXMP_CORE_PLAYER
 	/* Volume translation table (for PTM, ARCH, COCO) */
 	if (m->vol_table) {
 		finalvol = m->volbase == 0xff ?
 		    m->vol_table[finalvol >> 2] << 2 :
 		    m->vol_table[finalvol >> 4] << 4;
 	}
+#endif
 
 	if (HAS_QUIRK(QUIRK_INSVOL)) {
 		finalvol = (finalvol * instrument->vol * xc->gvl) >> 12;
@@ -411,7 +447,10 @@ static void process_frequency(struct context_data *ctx, int chn, int t, int act)
 		}
 	}
 
-	period = xc->period + extras_get_period(ctx, xc);
+	period = xc->period;
+#ifndef LIBXMP_CORE_PLAYER
+	period += extras_get_period(ctx, xc);
+#endif
 
 	linear_bend = period_to_bend(period + vibrato, xc->note,
 				HAS_QUIRK(QUIRK_MODRNG), xc->gliss,
@@ -433,7 +472,9 @@ static void process_frequency(struct context_data *ctx, int chn, int t, int act)
 		linear_bend += (100 << 7) * arp;
 	}
 
+#ifndef LIBXMP_CORE_PLAYER
 	linear_bend += extras_get_linear_bend(ctx, xc);
+#endif
 
 	/* For xmp_get_frame_info() */
 	xc->info_pitchbend = linear_bend >> 7;
@@ -525,6 +566,7 @@ static void update_volume(struct context_data *ctx, int chn, int t)
 			xc->volume += xc->vol.slide;
 		}
 
+#ifndef LIBXMP_CORE_PLAYER
 		if (TEST_PER(VOL_SLIDE)) {
 			if (xc->vol.slide > 0 && xc->volume > m->volbase) {
 				xc->volume = m->volbase;
@@ -535,6 +577,7 @@ static void update_volume(struct context_data *ctx, int chn, int t)
 				RESET_PER(VOL_SLIDE);
 			}
 		}
+#endif
 
 		if (TEST(VOL_SLIDE_2)) {
 			xc->volume += xc->vol.slide2;
@@ -600,11 +643,14 @@ static void update_frequency(struct context_data *ctx, int chn, int t)
 		if (TEST(FINE_BEND)) {
 			xc->period += xc->freq.fslide;
 		}
+
+#ifndef LIBXMP_CORE_PLAYER
 		if (TEST(FINE_NSLIDE)) {
 			xc->note += xc->noteslide.fslide;
 			xc->period = note_to_period(xc->note, xc->finetune,
 						    HAS_QUIRK(QUIRK_LINEAR));
 		}
+#endif
 	}
 
 	/* Check for invalid periods (from Toru Egashira's NSPmod)
@@ -680,7 +726,9 @@ static void play_channel(struct context_data *ctx, int chn, int t)
 	if (!IS_VALID_INSTRUMENT_OR_SFX(xc->ins))
 		return;
 
+#ifndef LIBXMP_CORE_PLAYER
 	play_extras(ctx, xc, chn, t == 0 && TEST(NEW_INS|NEW_NOTE));
+#endif
 
 	/* Do cut/retrig */
 	if (TEST(RETRIG)) {
@@ -781,12 +829,14 @@ static void next_order(struct context_data *ctx)
 	p->pos = p->ord;
 	p->frame = 0;
 
+#ifndef LIBXMP_CORE_PLAYER
 	/* Reset persistent effects at new pattern */
 	if (HAS_QUIRK(QUIRK_PERPAT)) {
 		int chn;
 		for (chn = 0; chn < mod->chn; chn++)
 			p->xc_data[chn].per_flags = 0;
 	}
+#endif
 }
 
 static void next_row(struct context_data *ctx)
@@ -859,7 +909,9 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 {
 	struct context_data *ctx = (struct context_data *)opaque;
 	struct player_data *p = &ctx->p;
+#ifndef LIBXMP_CORE_PLAYER
 	struct mixer_data *s = &ctx->s;
+#endif
 	struct smix_data *smix = &ctx->smix;
 	struct module_data *m = &ctx->m;
 	struct xmp_module *mod = &m->mod;
@@ -941,6 +993,7 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 		goto err1;
 	}
 
+#ifndef LIBXMP_CORE_PLAYER
 	for (i = 0; i < p->virt.virt_channels; i++) {
 		struct channel_data *xc = &p->xc_data[i];
 		if (new_channel_extras(ctx, xc) < 0)
@@ -953,14 +1006,17 @@ int xmp_start_player(xmp_context opaque, int rate, int format)
 	}
 
 	m->synth->reset(ctx);
+#endif
 	reset_channels(ctx);
 
 	ctx->state = XMP_STATE_PLAYING;
 
 	return 0;
 
+#ifndef LIBXMP_CORE_PLAYER
     err2:
 	free(p->xc_data);
+#endif
     err1:
 	free(f->loop);
     err:
@@ -1045,11 +1101,7 @@ int xmp_play_frame(xmp_context opaque)
 			f->end_point--;
 		}
 
-		if (f->skip_fetch) {
-			f->skip_fetch = 0;
-		} else {
-			read_row(ctx, mod->xxo[p->ord], p->row);
-		}
+		read_row(ctx, mod->xxo[p->ord], p->row);
 	}
 
 	inject_event(ctx);
@@ -1127,24 +1179,30 @@ void xmp_end_player(xmp_context opaque)
 {
 	struct context_data *ctx = (struct context_data *)opaque;
 	struct player_data *p = &ctx->p;
-	struct module_data *m = &ctx->m;
 	struct flow_control *f = &p->flow;
+#ifndef LIBXMP_CORE_PLAYER
+	struct module_data *m = &ctx->m;
 	struct channel_data *xc;
 	int i;
+#endif
 
 	if (ctx->state < XMP_STATE_PLAYING)
 		return;
 
 	ctx->state = XMP_STATE_LOADED;
 
+#ifndef LIBXMP_CORE_PLAYER
 	/* Free channel extras */
 	for (i = 0; i < p->virt.virt_channels; i++) {
 		xc = &p->xc_data[i];
 		release_channel_extras(ctx, xc);
 	}
+#endif
 
 	virt_off(ctx);
+#ifndef LIBXMP_CORE_PLAYER
 	m->synth->deinit(ctx);
+#endif
 
 	free(p->xc_data);
 	free(f->loop);
