@@ -1,9 +1,23 @@
-/* Extended Module Player
+/* Extended Module Player core player
  * Copyright (C) 1996-2014 Claudio Matsuoka and Hipolito Carraro Jr
  *
- * This file is part of the Extended Module Player and is distributed
- * under the terms of the GNU Lesser General Public License. See COPYING.LIB
- * for more information.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
+ *
+ * The above copyright notice and this permission notice shall be included in
+ * all copies or substantial portions of the Software.
+ *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+ * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+ * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+ * THE SOFTWARE.
  */
 
 #include <string.h>
@@ -12,7 +26,10 @@
 #include "effects.h"
 #include "virtual.h"
 #include "period.h"
+
+#ifndef LIBXMP_CORE_PLAYER
 #include "med_extras.h"
+#endif
 
 
 static inline void copy_channel(struct player_data *p, int to, int from)
@@ -107,8 +124,12 @@ static void set_effect_defaults(struct context_data *ctx, int note,
 }
 
 
+#ifndef LIBXMP_CORE_PLAYER
 #define IS_TONEPORTA(x) ((x) == FX_TONEPORTA || (x) == FX_TONE_VSLIDE \
 		|| (x) == FX_PER_TPORTA)
+#else
+#define IS_TONEPORTA(x) ((x) == FX_TONEPORTA || (x) == FX_TONE_VSLIDE)
+#endif
 
 #define set_patch(ctx,chn,ins,smp,note) \
 	virt_setpatch(ctx, chn, ins, smp, note, 0, 0, 0)
@@ -161,10 +182,12 @@ static int read_event_mod(struct context_data *ctx, struct xmp_event *e, int chn
 			virt_resetchannel(ctx, chn);
 		}
 
+#ifndef LIBXMP_CORE_PLAYER
 		if (HAS_MED_CHANNEL_EXTRAS(*xc)) {
 			MED_CHANNEL_EXTRAS(*xc)->arp = 0;
 			MED_CHANNEL_EXTRAS(*xc)->aidx = 0;
 		}
+#endif
 	}
 
 	/* Check note */
@@ -249,7 +272,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	struct module_data *m = &ctx->m;
 	struct xmp_module *mod = &m->mod;
 	struct channel_data *xc = &p->xc_data[chn];
-	int note, key;
+	int note, key, ins;
 	struct xmp_subinstrument *sub;
 	int new_invalid_ins;
 	int is_toneporta;
@@ -258,6 +281,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	xc->flags = 0;
 	note = -1;
 	key = e->note;
+	ins = e->ins;
 	new_invalid_ins = 0;
 	is_toneporta = 0;
 	use_ins_vol = 0;
@@ -268,17 +292,25 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 
 	/* Check instrument */
 
+	/* Ignore invalid instruments. The last instrument, invalid or
+	 * not, is preserved in channel data (see read_event() below).
+	 * Fixes stray delayed notes in forgotten_city.xm.
+	 */
+	if (ins > 0 && !IS_VALID_INSTRUMENT(ins - 1)) {
+		ins = 0;
+	}
+
+	/* Do this regardless if the instrument is invalid or not */
 	if (e->ins) {
-		int ins = e->ins - 1;
 		SET(NEW_INS);
 		use_ins_vol = 1;
 		xc->fadeout = 0x10000;
 		xc->per_flags = 0;
 		RESET_NOTE(NOTE_RELEASE);
 
-		if (IS_VALID_INSTRUMENT(ins)) {
+		if (IS_VALID_INSTRUMENT(ins - 1)) {
 			if (!is_toneporta)
-				xc->ins = ins;
+				xc->ins = ins - 1;
 		} else {
 			new_invalid_ins = 1;
 
@@ -319,12 +351,12 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	}
 
 	/* FT2: Retrieve old instrument volume */
-	if (e->ins) {
+	if (ins) {
 		struct xmp_subinstrument *sub;
 
 		if (key == 0 || key >= XMP_KEY_OFF) {
 			/* Previous instrument */
-			sub = get_subinstrument(ctx, xc->ins_oinsvol, xc->key);
+			sub = get_subinstrument(ctx, xc->old_insvol, xc->key);
 
 			/* No note */
 			if (sub != NULL) {
@@ -345,7 +377,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 			} else {
 				xc->volume = 0;
 			}
-			xc->ins_oinsvol = xc->ins;
+			xc->old_insvol = xc->ins;
 			SET(NEW_VOL);
 		}
 	}
@@ -384,7 +416,7 @@ static int read_event_ft2(struct context_data *ctx, struct xmp_event *e, int chn
 	sub = get_subinstrument(ctx, xc->ins, xc->key);
 
 	set_effect_defaults(ctx, note, sub, xc, is_toneporta);
-	if (e->ins && sub != NULL) {
+	if (ins && sub != NULL) {
 		/* Reset envelopes on new instrument, see olympic.xm pos 10
 		 * But make sure we have an instrument set, see Letting go
 		 * pos 4 chn 20
@@ -874,7 +906,12 @@ static int read_event_smix(struct context_data *ctx, struct xmp_event *e, int ch
 
 int read_event(struct context_data *ctx, struct xmp_event *e, int chn)
 {
+	struct player_data *p = &ctx->p;
 	struct module_data *m = &ctx->m;
+	struct channel_data *xc = &p->xc_data[chn];
+
+	if (e->ins != 0)
+		xc->old_ins = e->ins;
 
 	if (chn >= m->mod.chn) {
 		return read_event_smix(ctx, e, chn);
